pub struct GitRemoteUrl {
pub host: String,
pub path: String,
}Expand description
Host + path split out of a parsed git remote URL.
host carries the bare hostname (port and userinfo removed). path carries
the URL path with leading/trailing slashes and a single optional trailing
.git removed; callers split it into owner/repo or group/project segments.
Fields
host: Stringpath: StringTrait Implementations
Sourceimpl Clone for GitRemoteUrl
impl Clone for GitRemoteUrl
Sourcefn clone(&self) -> GitRemoteUrl
fn clone(&self) -> GitRemoteUrl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitRemoteUrl
impl Debug for GitRemoteUrl
Sourceimpl PartialEq for GitRemoteUrl
impl PartialEq for GitRemoteUrl
Sourcefn eq(&self, other: &GitRemoteUrl) -> bool
fn eq(&self, other: &GitRemoteUrl) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GitRemoteUrl
impl StructuralPartialEq for GitRemoteUrl